<?php
namespace MascotCoreOitech\Widgets\FeatureBlock\Skins;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Skin_Base as Elementor_Skin_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Skin_Style8 extends Elementor_Skin_Base {

	protected function _register_controls_actions() {
		add_action( 'elementor/element/tm-ele-block-features/general/after_section_end', [ $this, 'register_layout_controls' ] );
	}

	public function get_id() {
		return 'skin-style8';
	}


	public function get_title() {
		return __( 'Skin Style8', 'mascot-core-oitech' );
	}


	public function register_layout_controls( Widget_Base $widget ) {
		$this->parent = $widget;

		//Current Background Styling
		$this->start_controls_section(
			'current_background_styling',
			[
				'label' => esc_html__( 'Current Background Styling', 'mascot-core-oitech' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'content_wrapper_custom_bg_color',
			[
				'label' => esc_html__( "Custom Background Color", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box:before' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_custom_bg_color_hover',
			[
				'label' => esc_html__( "Custom Background Color (Hover)", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2:hover .inner-box:before' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_icon_theme_colored',
			[
				'label' => esc_html__( "Make BG Theme Colored", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .feature-inner .feature-content' => 'background-color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .feature-current-item-style2 .feature-inner .feature-content::after' => 'border-top-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_responsive_control(
			'content_wrapper_theme_colored_hover',
			[
				'label' => esc_html__( "Make BG Theme Colored (Hover)", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2:hover .feature-inner .feature-content' => 'background-color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .feature-current-item-style2:hover .feature-inner .feature-content::after' => 'border-top-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_section();




		//Icon Current Styling
		$this->start_controls_section(
			'current_icon_styling',
			[
				'label' => esc_html__( 'Current Icon Styling', 'mascot-core-oitech' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_color',
			[
				'label' => esc_html__( "Custom Icon Color", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .feature-inner .feature-content .feature-icon .icon i::before' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_color_hover',
			[
				'label' => esc_html__( "Custom Icon Color (Hover)", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2:hover .feature-inner .feature-content .feature-icon .icon i::before' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_theme_colored',
			[
				'label' => esc_html__( "Make icon Theme Colored", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .feature-inner .feature-content .feature-icon .icon i::before' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_theme_colored_hover',
			[
				'label' => esc_html__( "Make Icon Theme Colored (Hover)", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2:hover .feature-inner .feature-content .feature-icon .icon i::before' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);

		//icon Background Styling
		$this->add_responsive_control(
			'content_wrapper_current_bg_color',
			[
				'label' => esc_html__( "Custom Background Color", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .feature-inner .feature-content .feature-icon .icon' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .feature-current-item-style2 .feature-inner .feature-content .feature-icon .icon::after' => 'border-top-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_bg_color_hover',
			[
				'label' => esc_html__( "Custom Background Color (Hover)", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2:hover .feature-inner .feature-content .feature-icon .icon' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .feature-current-item-style2:hover .feature-inner .feature-content .feature-icon .icon::after' => 'border-top-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_colored',
			[
				'label' => esc_html__( "Make BG Theme Colored", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .feature-inner .feature-content .feature-icon .icon' => 'background-color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .feature-current-item-style2 .feature-inner .feature-content .feature-icon .icon::after' => 'border-top-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_theme_colored_hover',
			[
				'label' => esc_html__( "Make BG Theme Colored (Hover)", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2:hover .feature-inner .feature-content .feature-icon .icon' => 'background-color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .feature-current-item-style2:hover .feature-inner .feature-content .feature-icon .icon::after' => 'border-top-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_section();


		//icon Title Styling
		$this->start_controls_section(
			'title_options_styling',
			[
				'label' => esc_html__( 'Title Styling', 'mascot-core-oitech' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'title_text_color',
			[
				'label' => esc_html__( "Text Color", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_text_color_item_hover',
			[
				'label' => esc_html__( "Text Color", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_theme_colored',
			[
				'label' => esc_html__( "Title Theme Colored", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_control(
			'title_theme_colored_hover',
			[
				'label' => esc_html__( "Title Theme Colored (Title Hover)", 'mascot-core-oitech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title:hover' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => esc_html__( 'Typography', 'mascot-core-oitech' ),
				'selector' => '{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title',
			]
		);
		$this->add_responsive_control(
			'title_margin',
			[
				'label' => esc_html__( 'Title Margin', 'mascot-core-oitech' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'title_padding',
			[
				'label' => esc_html__( 'Title Padding', 'mascot-core-oitech' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style2 .inner-box .feature-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();

	}

	public function render() {
		$settings = $this->parent->get_settings_for_display();

		//link url
		$settings['target'] = ( $settings['link'] && $settings['link']['is_external'] ) ? ' target="_blank"' : '';
		$settings['url'] = ( $settings['link'] && $settings['link']['url'] ) ? $settings['link']['url'] : '';



		//classes
		$classes = array();
		$classes[] = $settings['custom_css_class'];

		if( $settings['animate_icon_on_hover'] ) {
			$classes[] = 'animate-icon-on-hover animate-icon-'.$settings['animate_icon_on_hover'];
		}

		$settings['classes'] = $classes;

		//enqueue css
		$direction_suffix = is_rtl() ? '.rtl' : '';
		wp_enqueue_style( 'tm-block-feature-current-item-style8', MASCOT_CORE_OITECH_URL_PATH . 'assets/css/shortcodes/block-features/block-feature-current-item-style8' . $direction_suffix . '.css' );


		//icon classes
		$icon_classes = array();
		$settings['icon_classes'] = $icon_classes;

		//button classes
		$settings['btn_classes'] = mascot_core_prepare_button_classes_from_params( $settings );

		//title classes
		$title_classes = array();
		$settings['title_classes'] = $title_classes;

		//subtitle classes
		$subtitle_classes = array();
		$settings['subtitle_classes'] = $subtitle_classes;

		//icon classes
		$icon_classes = array();
		$settings['icon_classes'] = $icon_classes;

		$settings['settings'] = $settings;

		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
		$html = mascot_core_oitech_get_shortcode_template_part( 'block-features-' . $settings['_skin'], null, 'block-features/tpl', $settings, true );

		echo $html;
	}
}